@@ -45,3 +45,9 @@ CREATE TABLE entrytags (
 	tag NOT NULL,
 	UNIQUE(entry, tag)
 );
+
+CREATE TABLE rubric (
+	schema_version NOT NULL
+);
+
+INSERT INTO rubric (schema_version) VALUES (10);
